=== modified file 'configure.ac'
--- configure.ac	2008-11-02 14:47:26 +0000
+++ configure.ac	2008-11-03 06:33:47 +0000
@@ -339,8 +339,8 @@
 case "$target_os" in
   *solaris*)
   dnl Do we need both of these? 
+  CFLAGS="${CFLAGS} -D_XOPEN_SOURCE=600"
   CXXFLAGS="${CXXFLAGS} -D__C99FEATURES__"
-  CFLAGS="${CFLAGS} -D_XOPEN_SOURCE=600"
   ;;
 esac
 
@@ -415,10 +415,10 @@
   dnl I'm cheating here and sticking C99 support in SYMBOLS_FLAGS
   SYMBOLS_FLAGS=""
   DEBUG_OPTIMIZE_CC=""
-  #OPTIMIZE_CFLAGS="-xO4 -xlibmil -xdepend -Xa -xstrconst -mt -D_FORTEC_"
   OPTIMIZE_CFLAGS="-xO4 -xlibmil -xdepend -Xa -mt -xstrconst -D_FORTEC_"
   DEBUG_OPTIMIZE_CXX=""
-  OPTIMIZE_CXXFLAGS="-xO4 -xlibmil -library=stlport4 -mt -D_FORTEC_ -xlang=c99 -compat=5"
+  #Put back in once isnan is figured out
+  OPTIMIZE_CXXFLAGS="-xO4 -xlibmil -mt -D_FORTEC_ -xlang=c99 -compat=5 -library=stlport4"
 fi
 
 dnl TODO: Remove this define once we are using 2.61 across the board.

=== modified file 'drizzled/field/real.cc'
--- drizzled/field/real.cc	2008-11-02 08:50:37 +0000
+++ drizzled/field/real.cc	2008-11-03 06:33:47 +0000
@@ -22,6 +22,7 @@
 #include <drizzled/field/real.h>
 #include <drizzled/error.h>
 #include CMATH_H
+#include <drizzled/util/math.h>
 
 #if defined(CMATH_NAMESPACE)
 using namespace CMATH_NAMESPACE;

=== modified file 'drizzled/functions/func.cc'
--- drizzled/functions/func.cc	2008-11-02 03:17:55 +0000
+++ drizzled/functions/func.cc	2008-11-03 06:33:47 +0000
@@ -27,6 +27,10 @@
 #include <drizzled/sql_list.h>
 
 #include <drizzled/functions/int.h>
+#if defined(HAVE_IEEEFP_H)
+# include <ieeefp.h>
+#endif
+
 #include CMATH_H
 
 #if defined(CMATH_NAMESPACE)

=== modified file 'drizzled/functions/func.h'
--- drizzled/functions/func.h	2008-10-20 04:28:21 +0000
+++ drizzled/functions/func.h	2008-11-03 06:33:47 +0000
@@ -27,13 +27,6 @@
 #include <drizzled/sql_list.h>
 
 
-#ifdef HAVE_IEEEFP_H
-extern "C"        /* Bug in BSDI include file */
-{
-#include <ieeefp.h>
-}
-#endif
-
 class Item_func :public Item_result_field
 {
 protected:

=== modified file 'drizzled/functions/real.cc'
--- drizzled/functions/real.cc	2008-11-02 08:50:37 +0000
+++ drizzled/functions/real.cc	2008-11-03 06:33:47 +0000
@@ -22,6 +22,9 @@
 
 #include CSTDINT_H
 #include <cassert>
+#if defined(HAVE_IEEEFP_H)
+# include <ieeefp.h>
+#endif
 #include CMATH_H
 
 #if defined(CMATH_NAMESPACE)

=== modified file 'drizzled/global.h'
--- drizzled/global.h	2008-11-02 08:50:37 +0000
+++ drizzled/global.h	2008-11-03 06:33:47 +0000
@@ -278,4 +278,8 @@
 # define _DTRACE_VERSION 0
 #endif
 
+#if !defined(HAVE_ISNAN) && defined(__cplusplus)
+template<type T>
+isnan<T>( 
+#endif
 #endif /* DRIZZLE_SERVER_GLOBAL_H */

=== modified file 'drizzled/serialize/binlog_encoding.h'
--- drizzled/serialize/binlog_encoding.h	2008-10-06 22:45:37 +0000
+++ drizzled/serialize/binlog_encoding.h	2008-11-03 06:33:47 +0000
@@ -8,8 +8,10 @@
 
 #define LENGTH_ENCODE_MAX_BYTES (sizeof(size_t) + 1)
 
+using std::size_t;
+
 inline unsigned char *
-length_encode(size_t length, unsigned char *buf)
+length_encode(std::size_t length, unsigned char *buf)
 {
   unsigned char *ptr= buf;
   assert(length > 1);
@@ -38,7 +40,7 @@
       }
     }
     // Clear the remaining bytes up to the next power of two
-    memset(ptr + 1, 0, pow2 - (ptr - buf));
+    std::memset(ptr + 1, 0, pow2 - (ptr - buf));
     *buf= log2m1;
     ptr= buf + pow2 + 1;
   }

=== modified file 'drizzled/serialize/binlog_reader.cc'
--- drizzled/serialize/binlog_reader.cc	2008-10-23 02:48:56 +0000
+++ drizzled/serialize/binlog_reader.cc	2008-11-03 06:33:47 +0000
@@ -3,6 +3,7 @@
 #include "binary_log.h"
 
 #include <iostream>
+#include <fstream>
 
 #include <google/protobuf/io/coded_stream.h>
 #include <google/protobuf/io/zero_copy_stream_impl.h>
@@ -64,8 +65,12 @@
   if (optind > argc)
     print_usage_and_exit(argv[0]);
 
-  int fd = open(file_name, O_RDONLY);
-  ZeroCopyInputStream* raw_input = new FileInputStream(fd);
+  filebuf fb;
+
+  fb.open(file_name, std::ios::in);
+  istream is(&fb);
+
+  ZeroCopyInputStream* raw_input = new IstreamInputStream(&is);
   CodedInputStream *coded_input = new CodedInputStream(raw_input);
 
   BinaryLog::Event event;
@@ -74,5 +79,5 @@
 
   delete coded_input;
   delete raw_input;
-  close(fd);
+  fb.close();
 }

=== modified file 'drizzled/serialize/binlog_writer.cc'
--- drizzled/serialize/binlog_writer.cc	2008-10-23 02:48:56 +0000
+++ drizzled/serialize/binlog_writer.cc	2008-11-03 06:33:47 +0000
@@ -9,6 +9,7 @@
 #include <google/protobuf/io/coded_stream.h>
 
 #include <iostream>
+#include <fstream>
 #include <sstream>
 #include <string>
 #include <map>
@@ -17,6 +18,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
+using namespace std;
 using namespace google::protobuf::io;
 
 typedef std::map<std::string,std::string> Assign;
@@ -33,7 +35,7 @@
        << "    --output name    Append query to file <name> (default: 'log.bin')\n"
        << "    --set var=val    Set value of user variable for query\n"
        << "    --trans-id <id>  Set transaction id to <id>\n"
-       << std::flush;
+       << flush;
   exit(1);
 }
 
@@ -41,7 +43,7 @@
 void
 write_query(CodedOutputStream* out,
             unsigned long trans_id,
-            const std::string& query,
+            const string& query,
             const Assign& assign)
 {
   BinaryLog::Query *message = new BinaryLog::Query;
@@ -70,7 +72,6 @@
 
 int main(int argc, char *argv[])
 {
-  using std::ios;
   GOOGLE_PROTOBUF_VERIFY_VERSION;
 
   static struct option options[] = {
@@ -97,8 +98,8 @@
       char *pos= strchr(optarg, '=');
       if (!pos)
         pos= end;
-      const std::string key(optarg, pos);
-      const std::string value(pos == end ? end : pos+1, end);
+      const string key(optarg, pos);
+      const string value(pos == end ? end : pos+1, end);
       assign[key]= value;
     }
 
@@ -115,23 +116,22 @@
   if (optind >= argc)
     print_usage_and_exit(argv[0]);
 
-  int outfd= open(file_name, O_WRONLY | O_CREAT | O_APPEND, 0644);
-  if (outfd < 0)
-  {
-    perror("open");
-    exit(1);
-  }
-
-  ZeroCopyOutputStream* raw_output = new FileOutputStream(outfd);
+  filebuf fb;
+
+  fb.open(file_name, ios::app | ios::out);
+
+  ostream os(&fb);
+
+  ZeroCopyOutputStream* raw_output = new OstreamOutputStream(&os);
   CodedOutputStream* coded_output = new CodedOutputStream(raw_output);
 
-  std::stringstream sout;
+  stringstream sout;
   sout << ioutil::join(" ", &argv[optind], &argv[argc]);
 
   write_query(coded_output, trans_id, sout.str(), assign);
 
   delete coded_output;
   delete raw_output;
-  close(outfd);
+  fb.close();
   exit(0);
 }

